#!/bin/sh

# The source here is entirely from an openssh-3.6.* distribution
# EXCEPT for the following:
#	openssh-3.6.sh		this file
#	openssh-3.6-patches	the changes to be applied
#	opensshd		our /etc/init.d script

set -x
set -e
ROOTMACH="$ROOT/$MACH"
OPENSSL=`cd ../openssl-*; pwd`
ZLIB=`cd ../zlib-*; pwd`

# Want to link with just-built opensrc libraries.
# We also need to keep LD as CC.
LDFLAGS="$LDFLAGS -L$ROOTMACH/usr/lib"
export LDFLAGS
LD=$CC
export LD

[ -f openssh-3.6-been-patched ] || {
	patch -p1 -i openssh-3.6-patches
	date >openssh-3.6-been-patched
}

./configure --with-privsep-user=noaccess \
	--prefix=/usr --sysconfdir=/etc \
	--libexecdir=/usr/sbin --with-pid-dir=/etc \
	--build=i686-sco-sysv5 --host=i386-sco-sysv5 \
	--with-ssl-dir=$OPENSSL --with-rpath=yes

# First add -I$ZLIB to the preprocessing flags as the cross compiler
# will not find /usr/include/zlib.h.
# We needed --with_rpath to get the configure invocation to finish,
# but we don't want it to show up in the binaries to be built.

ed Makefile <<!
/^CPPFLAGS=/s;\$; -I$ZLIB;
/^LDFLAGS=.*-R/s;-R$OPENSSL;;
w
q
!

${MAKE-make}

mkdir -p $ROOTMACH/etc/init.d || echo nevermind...

sh $INS 755 root sys $ROOTMACH/etc/init.d/opensshd opensshd
sh $INS 644 root sys $ROOTMACH/usr/share/Ssh.bin scard/Ssh.bin

sh $INS 644 root sys $ROOTMACH/etc/moduli moduli
sh $INS 644 root sys $ROOTMACH/etc/ssh_config ssh_config
sh $INS 644 root sys $ROOTMACH/etc/sshd_config sshd_config

sh $INS 755 root sys $ROOTMACH/usr/bin/scp scp
sh $INS 755 root sys $ROOTMACH/usr/bin/sftp sftp
sh $INS 755 root sys $ROOTMACH/usr/bin/ssh ssh
sh $INS 755 root sys $ROOTMACH/usr/bin/ssh-add ssh-add
sh $INS 755 root sys $ROOTMACH/usr/bin/ssh-agent ssh-agent
sh $INS 755 root sys $ROOTMACH/usr/bin/ssh-keygen ssh-keygen
sh $INS 755 root sys $ROOTMACH/usr/bin/ssh-keyscan ssh-keyscan
sh $INS 755 root sys $ROOTMACH/usr/sbin/sftp-server sftp-server
sh $INS 755 root sys $ROOTMACH/usr/sbin/ssh-keysign ssh-keysign
sh $INS 755 root sys $ROOTMACH/usr/sbin/sshd sshd

MAN=$ROOTMACH/usr/lib/scohelp/en_US.ISO8859-1/man
mkdir -p $MAN/man1 $MAN/man5 $MAN/man8 || echo nevermind...
sh $INS 644 root sys $MAN/man1/scp.1 scp.1
sh $INS 644 root sys $MAN/man1/sftp.1 sftp.1
sh $INS 644 root sys $MAN/man1/ssh.1 ssh.1
sh $INS 644 root sys $MAN/man1/ssh-add.1 ssh-add.1
sh $INS 644 root sys $MAN/man1/ssh-agent.1 ssh-agent.1
sh $INS 644 root sys $MAN/man1/ssh-keygen.1 ssh-keygen.1
sh $INS 644 root sys $MAN/man1/ssh-keyscan.1 ssh-keyscan.1
sh $INS 644 root sys $MAN/man5/ssh_config.5 ssh_config.5
sh $INS 644 root sys $MAN/man5/sshd_config.5 sshd_config.5
sh $INS 644 root sys $MAN/man8/sftp-server.8 sftp-server.8
sh $INS 644 root sys $MAN/man8/ssh-keysign.8 ssh-keysign.8
sh $INS 644 root sys $MAN/man8/sshd.8 sshd.8

set +e
rm -f $ROOTMACH/usr/bin/slogin $MAN/man1/slogin.1
ln -s $ROOTMACH/usr/bin/ssh $ROOTMACH/usr/bin/slogin
ln -s $MAN/man1/ssh.1 $MAN/man1/slogin.1
